covasim.data package
====================

.. automodule:: covasim.data
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   covasim.data.country_age_data
   covasim.data.household_size_data
   covasim.data.loaders
   covasim.data.state_age_data
